@@ -15,7 +15,7 @@ use CodeGen::Protection::Types qw(
   Optional
 );
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 our @EXPORT_OK = qw(
   create_protected_code
   rewrite_code
@@ -53,8 +53,8 @@ sub _rewritten {
 }
 
 sub _use_module {
-    my $type  = shift;
-    my $class = "CodeGen::Protection::Format::$type";
+    my $format = shift;
+    my $class  = "CodeGen::Protection::Format::$format";
     use_module($class);
     return $class;
 }
@@ -73,7 +73,7 @@ CodeGen::Protection - Safely rewrite parts of generated code
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -96,6 +96,8 @@ version 0.04
 
 =head1 DESCRIPTION
 
+If you might find the L<Tutorial|CodeGen::Protection::Tutorial> to be useful.
+
 Code that writes code can be a powerful tool, especially when you need to
 generate lots of boilerplate. However, when a developer takes the generated
 code, they can easily rewrite that code in a way that no longer works, or make
@@ -111,11 +113,11 @@ partial rewrite of documents. At the present time, we support Perl and HTML.
 In short, we wrap your "protected" (C<protected_code>) code in start and end
 comments, with checksums for the code:
 
-    #<<< CodeGen::Protection::Perl 0.01. Do not touch any code between this and the end comment. Checksum: fa97a021bd70bf3b9fa3e52f203f2660
+    #<<< CodeGen::Protection::Format::Perl 0.01. Do not touch any code between this and the end comment. Checksum: fa97a021bd70bf3b9fa3e52f203f2660
     
     # protected code goes here
 
-    #>>> CodeGen::Protection::Perl 0.01. Do not touch any code between this and the start comment. Checksum: fa97a021bd70bf3b9fa3e52f203f2660
+    #>>> CodeGen::Protection::Format::Perl 0.01. Do not touch any code between this and the start comment. Checksum: fa97a021bd70bf3b9fa3e52f203f2660
 
 Or:
 
