@@ -15,7 +15,7 @@ requires qw(
   VERSION
 );
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 has existing_code => (
     is        => 'ro',
@@ -112,7 +112,7 @@ sub _extract_before_and_after {
     my $name       = $self->name;
     if ( $text !~ $extract_re ) {
         croak(
-            "Could not find the $type start and end markers in text for $name."
+            "Could not find the $type start and end markers in existing_code for $name."
         );
     }
     my $digest_start = $+{digest_start};
@@ -124,11 +124,10 @@ sub _extract_before_and_after {
         );
     }
 
-    if (  !$self->overwrite
-        && $digest_start ne $self->_get_checksum( $+{body} ) )
-    {
+    my $expected = $self->_get_checksum( $+{body} );
+    if ( !$self->overwrite && $digest_start ne $expected ) {
         croak(
-            "Checksum ($digest_start) did not match text. Set 'overwrite' to true to ignore this for $type $name"
+            "Checksum ($digest_start) did not match expected checksum ($expected). Set 'overwrite' to true to ignore this for $type $name"
         );
     }
     my $before = $+{before} // '';
@@ -145,7 +144,8 @@ sub _extract_body {
     my $type       = $self->document_type;
     if ( $text !~ $extract_re ) {
         croak(
-            "Could not find the $type start and end markers in text for $name");
+            "Could not find the $type start and end markers in protected_code for $name"
+        );
     }
     my $digest_start = $+{digest_start};
     my $digest_end   = $+{digest_end};
@@ -279,7 +279,7 @@ CodeGen::Protection::Role - Role to help rewrite parts of documents
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
